
/**
 * 解释日期时间字符串，并转换成日期格式
 * @param {String} dateStr 日期字符串，必须是10或19位
 */
Date.parseDateTime = function(dateStr){
	if(dateStr && dateStr.length == 10){
		var year = parseInt(dateStr.substr(0, 4));
		var month = parseInt(dateStr.substr(5, 2)) - 1;
		var day = parseInt(dateStr.substr(8, 2));
		return new Date(year, month, day);
	}else if(dateStr && dateStr.length == 16){
		var year = parseInt(dateStr.substr(0, 4));
		var month = parseInt(dateStr.substr(5, 2)) - 1;
		var day = parseInt(dateStr.substr(8, 2));
		var hours = parseInt(dateStr.substr(11, 2));
		var minutes = parseInt(dateStr.substr(14, 2));
		var seconds = 0;
		return new Date(year, month, day, hours, minutes, seconds);
	}else if(dateStr && dateStr.length == 19){
		var year = parseInt(dateStr.substr(0, 4));
		var month = parseInt(dateStr.substr(5, 2)) - 1;
		var day = parseInt(dateStr.substr(8, 2));
		var hours = parseInt(dateStr.substr(11, 2));
		var minutes = parseInt(dateStr.substr(14, 2));
		var seconds = parseInt(dateStr.substr(17, 2));
		return new Date(year, month, day, hours, minutes, seconds);
	}
	return new Date();
}

/**
 * 对Date的扩展，将 Date 转化为指定格式的String
 * 月(M)、日(d)、小时(h)、分(m)、秒(s)、季度(q) 可以用 1-2 个占位符，
 * 年(y)可以用 1-4 个占位符，毫秒(S)只能用 1 个占位符(是 1-3 位的数字)
 * 例子：
 * (new Date()).Format("yyyy-MM-dd hh:mm:ss.S") ==> 2006-07-02 08:09:04.423
 * (new Date()).Format("yyyy-M-d h:m:s.S")      ==> 2006-7-2 8:9:4.18
 * @param {String} fmt 格式字符串
 */
Date.prototype.format = function(fmt) {
	var o = {
		"M+" : this.getMonth() + 1, //月份
		"d+" : this.getDate(), //日
		"h+" : this.getHours(), //小时
		"m+" : this.getMinutes(), //分
		"s+" : this.getSeconds(), //秒
		"q+" : Math.floor((this.getMonth() + 3) / 3), //季度
		"S" : this.getMilliseconds() //毫秒
	};
	if(/(y+)/.test(fmt))
		fmt = fmt.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
	for(var k in o)
	if(new RegExp("(" + k + ")").test(fmt))
		fmt = fmt.replace(RegExp.$1, (RegExp.$1.length == 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k]).length)));
	return fmt;
}

Date.prototype.toDate = function(){
	return this.format("yyyy-MM-dd");
}

Date.prototype.toDateTime = function(){
	return this.format("yyyy-MM-dd hh:mm:ss");
}

Date.prototype.toTDateTime = function(){
	return this.format("yyyy-MM-ddThh:mm:ss");
}

Date.prototype.toTime = function(){
	return this.format("hh:mm:ss");
}

Date.prototype.toHHMM = function(){
	return this.format("hh:mm");
}

/**
 * 时间、日期加减
 */
Date.prototype.addSeconds = function(seconds) {
	return new Date(this.getTime() + seconds*1000);
}

Date.prototype.addMinutes = function(minutes) {
	return new Date(this.getTime() + minutes*60*1000);
}

Date.prototype.addHours = function(hours) {
	return new Date(this.getTime() + hours*60*60*1000);
}

Date.prototype.addDay = function(days) {
	return new Date(this.getTime() + days*24*60*60*1000);
}

Date.prototype.addMonth = function(months) {
	var arr_month_days = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
	var o = {
		"year" : this.getFullYear(),//年
		"month" : this.getMonth(), //月份
		"date" : this.getDate(), //日
		"hours" : this.getHours(), //小时
		"minutes" : this.getMinutes(), //分
		"seconds" : this.getSeconds(), //秒
		"milliseconds" : this.getMilliseconds() //毫秒
	};
	//润年，二月29天
	if((o.year%4 == 0 && o.year%100 != 0) || o.year%400 == 0){
		arr_month_days[1] = 29;
	}
	o.year += parseInt(months/12);
	o.month += months%12;
	if(o.month < 0){
		o.month += 12;
		o.year -= 1;
	}else if(o.month >= 12){
		o.month -= 12;
		o.year += 1;
	}
	if(o.date > arr_month_days[o.month]){
		o.date = arr_month_days[o.month];
	}
	return new Date(o.year, o.month, o.date, o.hours, o.minutes, o.seconds, o.milliseconds);
}

/**
 * 加减日历
 * @param date 某日期
 * @param interval 间隔（日）
 */
function dateAdd(date, interval){
	return new Date(date.getTime() + 24*60*60*1000*interval);
}

//判断是 今天、昨天、明天、后天
function getFormatDay(select){
	var currentDate = new Date();
	var todayStr = getDateString( currentDate);
	select = getDateString( select);
	if(todayStr == select){
		return "今天";
	}
   var date= dateAdd(currentDate, 1);
   var dateStr = getDateString(date);
    if(dateStr == select){
		return "明天";
	}
    date= dateAdd(currentDate, 2);
    dateStr = getDateString(date);
    if(dateStr == select){
		return "后天";
	}
    return "";
}
//获取星期几
function getWeek(date){
	var week = [
   		"星期日",
   		"星期一",
   		"星期二",
   		"星期三",
   		"星期四",
   		"星期五",
   		"星期六"
   	];
    return week[date.getDay()];
}

/**
 * 获取日期字符串
 * @param date 某日期
 */
function getDateString(date){
	var result = [];
	result.push(date.getFullYear());
	result.push("-");
	if(date.getMonth() < 9){
		result.push("0");
	}
	result.push(date.getMonth() + 1);
	result.push("-");
	if(date.getDate() < 10){
		result.push("0");
	}
	result.push(date.getDate());
	return result.join("");
}

/**
 * 获取日期字符串
 * @param date 某日期
 */
function getDateMonthString(date){
	var result = [];
	result.push(date.getMonth() + 1);
	result.push("月");
	result.push(date.getDate());
	result.push("日");
	return result.join("");
}

/**
 * 计算两个日期的相差天数
 * 日期格式2008-05-04
 */
function DateDiff(startDate, endDate){
   var aDate, oDate1, oDate2, iDays ;
   aDate = startDate.split('-');
   oDate1 = new Date(aDate[1]+'-'+aDate[2]+'-'+aDate[0]) ;
   aDate = endDate.split('-');
   oDate2 = new Date(aDate[1]+'-'+ aDate[2] +'-'+aDate[0]);
   iDays = parseInt(Math.abs(oDate1 -oDate2)/1000/60/60/24); //把相差的毫秒数转换为天数
   return iDays ;
}